@@ -7,8 +7,8 @@ import traceback
 import os
 import platform
 import json
+import pprint
 from copy import copy
-from basepy.asynclib.fluent import AsyncFluentSender
 from basepy.asynclib import datagram
 from basepy.common.log import LoggerLevel, LogRecord, BaseHandler
 
@@ -18,6 +18,7 @@ class StdoutHandler(BaseHandler):
         if stream is None:
             stream = sys.stdout
         self.stream = stream
+        self.isatty = stream.isatty()
         self.format_str = "[{created}] [{hostname}.{process}] [{level}] [{name}] [{message}]"
         self.level = level
         self.levelno = LoggerLevel.get_levelno(self.level, 0)
@@ -41,8 +42,11 @@ class StdoutHandler(BaseHandler):
         data['created'] = time.strftime("%Y-%m-%d %H:%M:%S %z", time.localtime(data['created']))
         extra_data = data.pop('data', None)
         msg = self.format_str.format(**data)
-        extra = ' '.join(map(lambda x: "[{} = {}]".format(x[0], json.dumps(x[1])), extra_data.items()))
-        if extra:
+        if len(extra_data) > 0:
+            if self.isatty:
+                extra = '{}{}{}'.format(self.terminator, pprint.pformat(extra_data), self.terminator)
+            else:
+                extra = ' '.join(map(lambda x: "[{} = {}]".format(x[0], json.dumps(x[1])), extra_data.items()))
             msg = ' '.join([msg, extra])
         return msg
 
@@ -100,35 +104,11 @@ class SocketHandler(BaseHandler):
     def __repr__(self):
         return '<%s [%s:%s(%s)]>' % (self.__class__.__name__, self.host, self.port, self.level)
 
-class FluentHandler(BaseHandler):
-    terminator = '\n'
-    def __init__(self, tag, host="127.0.0.1", port=24224, level="DEBUG", **kwargs):
-        self.tag = tag
-        self.host = host
-        self.port = port
-        self.fluentsender = AsyncFluentSender(tag, host=host, port=port)
-        self.level = level
-        self.levelno = LoggerLevel.get_levelno(self.level, 0)
-
-    def flush(self):
-        pass
-
-    async def emit(self, record):
-        try:
-            await self.fluentsender.emit(record.name, record.to_dict())
-        except Exception:
-            self.handle_error(record)
-
-
-    def __repr__(self):
-        return '<%s %s(%s)>' % (self.__class__.__name__, self.tag, self.level)
-
 
 class AsyncLoggerEngine:
     handler_class_map = {
         'stdout': StdoutHandler,
-        'socket': SocketHandler,
-        'fluent': FluentHandler
+        'socket': SocketHandler
     }
     def __init__(self, **kwargs):
         self.handlers = []
@@ -142,6 +122,12 @@ class AsyncLoggerEngine:
         self.buffer_queue_task = None
         self.will_close = False
 
+    @classmethod
+    def register_handler(cls, name, handler_cls):
+        if name not in cls.handler_class_map:
+            cls.handler_class_map[name] = handler_cls
+
+
     async def init(self, config=None):
         if config:
             handlers = config['handlers']
@@ -332,9 +318,12 @@ class AsyncLogger(object):
         self.name = name
         self.engine = engine or AsyncLoggerEngine()
         self.kwargs = kwargs
+        self.inited = False
 
     async def init(self, config=None):
-        await self.engine.init(config)
+        if not self.inited:
+            await self.engine.init(config)
+            self.inited = True
 
     def add(self, handler, level="DEBUG", log_format=None, queue=False, **kwargs):
         return self.engine.add(handler, level=level, log_format=log_format, queue=queue, **kwargs)
